@@ -29,28 +29,25 @@
  */
 #include "platform.h"
 #include <microhttpd.h>
-#if HAVE_CURL_CURL_H
 #include <curl/curl.h>
-#elif HAVE_GNURL_CURL_H
-#include <gnurl/curl.h>
-#endif
 #include <gnunet/gnunet_util_lib.h>
 #include <gnunet/gnunet_json_lib.h>
 #include <gnunet/gnunet_mhd_compat.h>
 #include "twister.h"
+#include "taler_twister_service.h"
 #include <jansson.h>
 #include <microhttpd.h>
 #include <zlib.h>
 
 
 #define TWISTER_LOG_INFO(...)                                  \
-  GNUNET_log (GNUNET_ERROR_TYPE_INFO, __VA_ARGS__)
+        GNUNET_log (GNUNET_ERROR_TYPE_INFO, __VA_ARGS__)
 #define TWISTER_LOG_DEBUG(...)                                  \
-  GNUNET_log (GNUNET_ERROR_TYPE_DEBUG, __VA_ARGS__)
+        GNUNET_log (GNUNET_ERROR_TYPE_DEBUG, __VA_ARGS__)
 #define TWISTER_LOG_WARNING(...)                                  \
-  GNUNET_log (GNUNET_ERROR_TYPE_WARNING, __VA_ARGS__)
+        GNUNET_log (GNUNET_ERROR_TYPE_WARNING, __VA_ARGS__)
 #define TWISTER_LOG_ERROR(...)                                  \
-  GNUNET_log (GNUNET_ERROR_TYPE_ERROR, __VA_ARGS__)
+        GNUNET_log (GNUNET_ERROR_TYPE_ERROR, __VA_ARGS__)
 
 #define REQUEST_BUFFER_MAX (1024 * 1024)
 #define UNIX_BACKLOG 500
@@ -63,8 +60,9 @@
  * @param rc return code from curl
  */
 #define LOG_CURL_EASY(level,fun,rc) \
-  GNUNET_log (level, _ ("%s failed at %s:%d: `%s'\n"), fun, __FILE__, __LINE__, \
-              curl_easy_strerror (rc))
+        GNUNET_log (level, _ ("%s failed at %s:%d: `%s'\n"), fun, __FILE__, \
+                    __LINE__, \
+                    curl_easy_strerror (rc))
 
 /* ******** Datastructures for HTTP handling ********** */
 
@@ -1272,6 +1270,7 @@ delete_object (struct MHD_Connection *con,
 {
   char *target;
   json_t *parent;
+  int ret_deletion = -1;
 
   if (NULL == hr->json)
     return GNUNET_NO;
@@ -1286,8 +1285,6 @@ delete_object (struct MHD_Connection *con,
   }
 
   /* here, element is the parent of the element to be deleted. */
-  int ret_deletion = -1;
-
   if (json_is_object (parent))
     ret_deletion = json_object_del (parent, target);
 
@@ -1415,7 +1412,7 @@ static void
 create_response_with_chaos_rate (struct HttpRequest *hr)
 {
   uint64_t random;
-  void *resp_buf;
+  const void *resp_buf;
   size_t resp_len;
 
   random = GNUNET_CRYPTO_random_u64 (GNUNET_CRYPTO_QUALITY_WEAK,
@@ -1437,9 +1434,8 @@ create_response_with_chaos_rate (struct HttpRequest *hr)
     resp_buf = hr->io_buf;
   }
   hr->response
-    = MHD_create_response_from_buffer (resp_len,
-                                       resp_buf,
-                                       MHD_RESPMEM_MUST_COPY);
+    = MHD_create_response_from_buffer_copy (resp_len,
+                                            resp_buf);
 }
 
 
@@ -2335,14 +2331,14 @@ open_unix_path (const char *path,
  * Crawl the configuration file and extracts the serving
  * method, TCP vs IPC, and the respective details (port/path/mode)
  *
- * @param cfg configuration handle.
+ * @param ccfg configuration handle.
  * @param port[out] port number to use
  * @param path[out] unix path for IPC.
  * @param mode[out] mode string for @a path.
  * @return #GNUNET_SYSERR if the parsing didn't succeed.
  */
 static int
-parse_serving_mean (const struct GNUNET_CONFIGURATION_Handle *cfg,
+parse_serving_mean (const struct GNUNET_CONFIGURATION_Handle *ccfg,
                     uint16_t *port,
                     char **path,
                     mode_t *mode)
@@ -2355,7 +2351,7 @@ parse_serving_mean (const struct GNUNET_CONFIGURATION_Handle *cfg,
 
 
   if (GNUNET_OK !=
-      GNUNET_CONFIGURATION_get_value_choice (cfg,
+      GNUNET_CONFIGURATION_get_value_choice (ccfg,
                                              "twister",
                                              "SERVE",
                                              choices,
@@ -2371,11 +2367,11 @@ parse_serving_mean (const struct GNUNET_CONFIGURATION_Handle *cfg,
   {
     *path = NULL;
 
-    if (GNUNET_OK != GNUNET_CONFIGURATION_get_value_number
-          (cfg,
-          "twister",
-          "HTTP_PORT",
-          &port_ull))
+    if (GNUNET_OK !=
+        GNUNET_CONFIGURATION_get_value_number (ccfg,
+                                               "twister",
+                                               "HTTP_PORT",
+                                               &port_ull))
     {
       GNUNET_log_config_missing (GNUNET_ERROR_TYPE_ERROR,
                                  "twister",
@@ -2388,11 +2384,11 @@ parse_serving_mean (const struct GNUNET_CONFIGURATION_Handle *cfg,
 
   /* serving via unix */
 
-  if (GNUNET_OK != GNUNET_CONFIGURATION_get_value_filename
-        (cfg,
-        "twister",
-        "SERVE_UNIXPATH",
-        path))
+  if (GNUNET_OK !=
+      GNUNET_CONFIGURATION_get_value_filename (ccfg,
+                                               "twister",
+                                               "SERVE_UNIXPATH",
+                                               path))
   {
     GNUNET_log_config_missing (GNUNET_ERROR_TYPE_ERROR,
                                "twister",
@@ -2400,11 +2396,11 @@ parse_serving_mean (const struct GNUNET_CONFIGURATION_Handle *cfg,
     return GNUNET_SYSERR;
   }
 
-  if (GNUNET_OK != GNUNET_CONFIGURATION_get_value_string
-        (cfg,
-        "twister",
-        "SERVE_UNIXMODE",
-        &modestring))
+  if (GNUNET_OK !=
+      GNUNET_CONFIGURATION_get_value_string (ccfg,
+                                             "twister",
+                                             "SERVE_UNIXMODE",
+                                             &modestring))
   {
     GNUNET_log_config_missing (GNUNET_ERROR_TYPE_ERROR,
                                "twister",
@@ -2945,61 +2941,63 @@ handle_set_response_code
 
 
 /**
- * Define "main" method using service macro.
+ * Main function.
  */
-GNUNET_SERVICE_MAIN
-  ("twister",
-  GNUNET_SERVICE_OPTION_NONE,
-  &run,
-  &client_connect_cb,
-  &client_disconnect_cb,
-  NULL,
-  GNUNET_MQ_hd_fixed_size (set_response_code,
-                           TWISTER_MESSAGE_TYPE_SET_RESPONSE_CODE,
-                           struct TWISTER_SetResponseCode,
+int
+main (int argc,
+      char *const *argv)
+{
+  struct GNUNET_MQ_MessageHandler mh[] = {
+    GNUNET_MQ_hd_fixed_size (set_response_code,
+                             TWISTER_MESSAGE_TYPE_SET_RESPONSE_CODE,
+                             struct TWISTER_SetResponseCode,
+                             NULL),
+    GNUNET_MQ_hd_var_size (modify_path_ul,
+                           TWISTER_MESSAGE_TYPE_MODIFY_PATH_UL,
+                           struct TWISTER_ModifyPath,
                            NULL),
-
-  GNUNET_MQ_hd_var_size (modify_path_ul,
-                         TWISTER_MESSAGE_TYPE_MODIFY_PATH_UL,
-                         struct TWISTER_ModifyPath,
-                         NULL),
-
-  GNUNET_MQ_hd_var_size (modify_path_dl,
-                         TWISTER_MESSAGE_TYPE_MODIFY_PATH_DL,
-                         struct TWISTER_ModifyPath,
-                         NULL),
-
-  GNUNET_MQ_hd_var_size (modify_header_dl,
-                         TWISTER_MESSAGE_TYPE_MODIFY_HEADER_DL,
-                         struct TWISTER_ModifyPath,
-                         NULL),
-
-  GNUNET_MQ_hd_fixed_size (malform_upload,
-                           TWISTER_MESSAGE_TYPE_MALFORM_UPLOAD,
-                           struct TWISTER_Malform,
+    GNUNET_MQ_hd_var_size (modify_path_dl,
+                           TWISTER_MESSAGE_TYPE_MODIFY_PATH_DL,
+                           struct TWISTER_ModifyPath,
                            NULL),
-
-  GNUNET_MQ_hd_fixed_size (malform,
-                           TWISTER_MESSAGE_TYPE_MALFORM,
-                           struct TWISTER_Malform,
+    GNUNET_MQ_hd_var_size (modify_header_dl,
+                           TWISTER_MESSAGE_TYPE_MODIFY_HEADER_DL,
+                           struct TWISTER_ModifyPath,
                            NULL),
+    GNUNET_MQ_hd_fixed_size (malform_upload,
+                             TWISTER_MESSAGE_TYPE_MALFORM_UPLOAD,
+                             struct TWISTER_Malform,
+                             NULL),
+    GNUNET_MQ_hd_fixed_size (malform,
+                             TWISTER_MESSAGE_TYPE_MALFORM,
+                             struct TWISTER_Malform,
+                             NULL),
+    GNUNET_MQ_hd_var_size (delete_path,
+                           TWISTER_MESSAGE_TYPE_DELETE_PATH,
+                           struct TWISTER_DeletePath,
+                           NULL),
+    GNUNET_MQ_hd_var_size (flip_path_ul,
+                           TWISTER_MESSAGE_TYPE_FLIP_PATH_UL,
+                           struct TWISTER_FlipPath,
+                           NULL),
+    GNUNET_MQ_hd_var_size (flip_path_dl,
+                           TWISTER_MESSAGE_TYPE_FLIP_PATH_DL,
+                           struct TWISTER_FlipPath,
+                           NULL),
+    GNUNET_MQ_handler_end ()
+  };
 
-  GNUNET_MQ_hd_var_size (delete_path,
-                         TWISTER_MESSAGE_TYPE_DELETE_PATH,
-                         struct TWISTER_DeletePath,
-                         NULL),
-
-  GNUNET_MQ_hd_var_size (flip_path_ul,
-                         TWISTER_MESSAGE_TYPE_FLIP_PATH_UL,
-                         struct TWISTER_FlipPath,
-                         NULL),
-
-  GNUNET_MQ_hd_var_size (flip_path_dl,
-                         TWISTER_MESSAGE_TYPE_FLIP_PATH_DL,
-                         struct TWISTER_FlipPath,
-                         NULL),
-
-  GNUNET_MQ_handler_end ());
+  return GNUNET_SERVICE_run_ (TWISTER_project_data (),
+                              argc,
+                              argv,
+                              "twister",
+                              GNUNET_SERVICE_OPTION_NONE,
+                              &run,
+                              &client_connect_cb,
+                              &client_disconnect_cb,
+                              NULL,
+                              mh);
+}
 
 
 /* end of taler-twister-service.c */
